@@ -1,5 +1,5 @@
 """Top-level package for Django Ultratenant."""
 
 __author__ = """HBN3tw0rk"""
-__email__ = 'lucas@cezimbra.tec.br'
-__version__ = '0.0.1'
+__email__ = "lucas@cezimbra.tec.br"
+__version__ = "0.0.1"
